abacusai.api_class.dataset_application_connector — AbacusAI documentation

# `abacusai.api_class.dataset_application_connector`

## Module Contents

### Classes

`DatasetConfig` | Helper class that provides a standard way to create an ABC using
`ConfluenceDatasetConfig` | Dataset config for Confluence Application Connector
`GoogleAnalyticsDatasetConfig` | Dataset config for Google Analytics Application Connector
`SharepointDatasetConfig` | Dataset config for Sharepoint Application Connector
`ZendeskDatasetConfig` | Dataset config for Zendesk Application Connector
`_DatasetConfigFactory` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.dataset_application_connector.DatasetConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  application_connector_type: abacusai.api_class.enums.ApplicationConnectorType
  classmethod _get_builder()

class abacusai.api_class.dataset_application_connector.ConfluenceDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Confluence Application Connector

  __post_init__()

class abacusai.api_class.dataset_application_connector.GoogleAnalyticsDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Google Analytics Application Connector :param location: The view id of the report in the connector to fetch :type location: str :param start_timestamp: Unix timestamp of the start of the period that will be queried :type start_timestamp: int, optional :param end_timestamp: Unix timestamp of the end of the period that will be queried :type end_timestamp: int, optional

  location: str
  start_timestamp: int
  end_timestamp: int
  __post_init__()

class abacusai.api_class.dataset_application_connector.SharepointDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Sharepoint Application Connector :param location: The regex location of the files to fetch :type location: str :param is_documentset: Whether the dataset is a document set :type is_documentset: bool :param csv_delimiter: If the file format is CSV, use a specific csv delimiter :type csv_delimiter: str, optional :param extract_bounding_boxes: Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True :type extract_bounding_boxes: bool, optional :param merge_file_schemas: Signifies if the merge file schema policy is enabled. If is_documentset is True, this is also set to True by default :type merge_file_schemas: bool, optional

  location: str
  is_documentset: bool
  csv_delimiter: str
  extract_bounding_boxes: bool
  merge_file_schemas: bool
  __post_init__()

class abacusai.api_class.dataset_application_connector.ZendeskDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Zendesk Application Connector

  __post_init__()

class abacusai.api_class.dataset_application_connector._DatasetConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'applicationConnectorType'
  config_class_map